"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@typescript-eslint/utils");
const utils_2 = require("@typescript-eslint/utils");
const is_immutable_type_1 = require("is-immutable-type");
const no_decreasing_immutability_1 = __importDefault(require("./no-decreasing-immutability"));
// eslint-disable-next-line functional/prefer-immutable-types
const ruleTester = new utils_2.ESLintUtils.RuleTester({
    parserOptions: {
        sourceType: "module",
        project: "./tsconfig.tests.json",
    },
    parser: "@typescript-eslint/parser",
});
// eslint-disable-next-line functional/no-expression-statements
ruleTester.run("no-decreasing-immutability", no_decreasing_immutability_1.default, {
    valid: [
        {
            filename: "file.ts",
            code: `
        const foo: Array<string> = [""];
        let bar: Readonly<string> = [""];        
        bar = foo;
      `,
        },
    ],
    invalid: [
        {
            filename: "file.ts",
            code: `
      const foo: ReadonlyArray<string> = [""];
      let bar: Array<string> = [""];        
      bar = foo;
      `,
            errors: [
                {
                    messageId: "errorStringGeneric",
                    type: utils_1.AST_NODE_TYPES.AssignmentExpression,
                    line: 4,
                    column: 7,
                    endColumn: 16,
                    data: {
                        sourceImmutability: is_immutable_type_1.Immutability[is_immutable_type_1.Immutability.ReadonlyDeep],
                        destinationImmutability: is_immutable_type_1.Immutability[is_immutable_type_1.Immutability.Mutable],
                    },
                },
            ],
        },
    ],
});
